Safecast Tracker
*************************

Command-line Safecast Tracker for APRS: ``safecast_tracker``


Examples
========


The following example uses the ``safecast_tracker`` command to connect to APRS-IS
as W2GMD and send a single-shot location frame containing k=v Safecast values:

::

    $ safecast_tracker -c W2GMD -p 12345 -c xx:xx:xx


See Also
^^^^^^^^
See ``$ safecast_tracker -h`` for more information.


Source
======
Github: https://github.com/ampledata/safecast_tracker

Author
======
Greg Albrecht W2GMD <gba@orionlabs.co>

Copyright
=========
Copyright 2015 Orion Labs, Inc.

License
=======
Apache License, Version 2.0
